@@ -14,7 +14,9 @@
 # You should have received a copy of the Artistic License along with this
 # program.  If not, see <http://www.perlfoundation.org/artistic_license_2_0>.
 #
-package Graphics::Fig::Color 1.0;
+package Graphics::Fig::Color;
+our $VERSION = 'v1.0.3';
+
 use strict;
 use warnings;
 use Carp;
