@@ -14,13 +14,14 @@
 # You should have received a copy of the Artistic License along with this
 # program.  If not, see <http://www.perlfoundation.org/artistic_license_2_0>.
 #
-package Graphics::Fig::Compound 1.0;
+package Graphics::Fig::Compound;
+our $VERSION = 'v1.0.3';
+
 use strict;
 use warnings;
 use utf8;
 use Carp;
 use POSIX qw(floor ceil);
-use Regexp::Common qw /number/;
 use Graphics::Fig::Parameters;
 
 #
